==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Revertendo o sistema, aguarde...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>A reversão falhou.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>As atualizações falharam.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>As atualizações falharam: foram interrompidas.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>As atualizações falharam: erro do DPKG.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>As atualizações falharam: espaço insuficiente em disco.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Reverter para %1 com backup em %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Cancelar e reiniciar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.38.1.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Revertendo o sistema, aguarde...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>A reversão falhou.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>As atualizações falharam.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>As atualizações falharam: foram interrompidas.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>As atualizações falharam: erro do DPKG.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>As atualizações falharam: espaço insuficiente em disco.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Reverter para %1 com backup em %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Cancelar e reiniciar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
</TS>
